#ifndef __DUMMY_H__
#define __DUMMY_H__

#define PROC_FILLMEM	0
#define PROC_FILLCMD	0
#define PROC_FILLENV	0
#define PROC_FILLTTY	0
#define PROC_FILLUSR	0
#define PROC_ANYTTY	0
#define PROC_UID	0

#define NR_TASKS	1024

typedef struct _proc_t proc_t;

struct _proc_t
{
	long pid, pcpu, pmem;
	long frequency, stime, utime, cutime, cstime, start_time;
	long size, rss, resident, nice, priority, share;
	char *user, *cmd, state;
};

#endif
